@@ -51,38 +51,38 @@
 #include <pyside2_qtcore_python.h>
 
 // Binded library includes
-#include <qarmature.h>
-#include <qpropertyupdatedchange.h>
-#include <qstaticpropertyvalueaddedchangebase.h>
-#include <qnodeid.h>
-#include <qnodedestroyedchange.h>
+#include <Qt3DCore/qcomponentremovedchange.h>
+#include <Qt3DCore/qnodeid.h>
+#include <Qt3DCore/qpropertyupdatedchange.h>
+#include <Qt3DCore/qpropertynodeaddedchange.h>
+#include <Qt3DCore/qentity.h>
+#include <Qt3DCore/qaspectengine.h>
+#include <Qt3DCore/qabstractaspect.h>
 #include <Qt3DCore/qtransform.h>
-#include <qjoint.h>
-#include <qcomponentremovedchange.h>
-#include <qpropertyvalueaddedchange.h>
-#include <qpropertyvalueaddedchangebase.h>
-#include <qstaticpropertyupdatedchangebase.h>
-#include <qstaticpropertyvalueremovedchangebase.h>
-#include <qnode.h>
-#include <qentity.h>
-#include <qnodecommand.h>
-#include <qpropertyvalueremovedchangebase.h>
-#include <qabstractaspect.h>
-#include <qpropertyupdatedchangebase.h>
-#include <qnodecreatedchange.h>
-#include <qcomponentaddedchange.h>
-#include <qpropertyvalueremovedchange.h>
-#include <qbackendnode.h>
-#include <qpropertynodeaddedchange.h>
-#include <qcomponent.h>
-#include <qdynamicpropertyupdatedchange.h>
-#include <qskeleton.h>
-#include <qscenechange.h>
-#include <qaspectengine.h>
-#include <qaspectjob.h>
-#include <qpropertynoderemovedchange.h>
-#include <qabstractskeleton.h>
-#include <qskeletonloader.h>
+#include <Qt3DCore/qcomponentaddedchange.h>
+#include <Qt3DCore/qpropertyvalueremovedchangebase.h>
+#include <Qt3DCore/qstaticpropertyupdatedchangebase.h>
+#include <Qt3DCore/qnode.h>
+#include <Qt3DCore/qskeleton.h>
+#include <Qt3DCore/qpropertyvalueremovedchange.h>
+#include <Qt3DCore/qnodecommand.h>
+#include <Qt3DCore/qpropertyvalueaddedchangebase.h>
+#include <Qt3DCore/qnodecreatedchange.h>
+#include <Qt3DCore/qcomponent.h>
+#include <Qt3DCore/qabstractskeleton.h>
+#include <Qt3DCore/qbackendnode.h>
+#include <Qt3DCore/qarmature.h>
+#include <Qt3DCore/qpropertyupdatedchangebase.h>
+#include <Qt3DCore/qskeletonloader.h>
+#include <Qt3DCore/qaspectjob.h>
+#include <Qt3DCore/qpropertynoderemovedchange.h>
+#include <Qt3DCore/qdynamicpropertyupdatedchange.h>
+#include <Qt3DCore/qscenechange.h>
+#include <Qt3DCore/qstaticpropertyvalueaddedchangebase.h>
+#include <Qt3DCore/qstaticpropertyvalueremovedchangebase.h>
+#include <Qt3DCore/qnodedestroyedchange.h>
+#include <Qt3DCore/qjoint.h>
+#include <Qt3DCore/qpropertyvalueaddedchange.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
