@@ -52,104 +52,104 @@
 #include <pyside2_qtcore_python.h>
 
 // Binded library includes
-#include <qlayerfilter.h>
-#include <qtexturegenerator.h>
-#include <qmultisampleantialiasing.h>
-#include <qlinewidth.h>
-#include <qstencilmask.h>
-#include <qlayer.h>
-#include <qcamera.h>
-#include <qbufferdatagenerator.h>
-#include <qfrustumculling.h>
-#include <qtexturewrapmode.h>
-#include <qcomputecommand.h>
-#include <qstenciltest.h>
-#include <qpaintedtextureimage.h>
-#include <qclipplane.h>
-#include <qrendersettings.h>
-#include <qshaderprogram.h>
-#include <qgeometry.h>
-#include <qstenciloperationarguments.h>
-#include <qbuffer.h>
-#include <qblendequationarguments.h>
-#include <qlevelofdetailswitch.h>
-#include <qobjectpicker.h>
-#include <qeffect.h>
-#include <qshaderdata.h>
-#include <qdithering.h>
-#include <qpointlight.h>
-#include <qmemorybarrier.h>
-#include <qabstractlight.h>
-#include <qalphacoverage.h>
-#include <qdirectionallight.h>
-#include <qraycaster.h>
-#include <qmaterial.h>
-#include <qnodraw.h>
-#include <qpicklineevent.h>
-#include <qdepthtest.h>
-#include <qspotlight.h>
-#include <qcameraselector.h>
-#include <qrenderaspect.h>
-#include <qpickpointevent.h>
-#include <qrendersurfaceselector.h>
-#include <qgeometryfactory.h>
-#include <qscissortest.h>
-#include <qframegraphnode.h>
-#include <qgraphicsapifilter.h>
-#include <qrendercapture.h>
-#include <qframegraphnodecreatedchange.h>
-#include <qpickevent.h>
-#include <qabstractfunctor.h>
-#include <qtextureimage.h>
-#include <qlevelofdetail.h>
-#include <qrendertargetselector.h>
-#include <qpolygonoffset.h>
-#include <qmesh.h>
-#include <qsortpolicy.h>
-#include <qattribute.h>
-#include <qrenderpassfilter.h>
-#include <qlevelofdetailboundingsphere.h>
-#include <qdispatchcompute.h>
-#include <qbuffercapture.h>
-#include <qscreenraycaster.h>
-#include <qtextureimagedatagenerator.h>
-#include <qabstracttexture.h>
-#include <qpickingsettings.h>
-#include <qseamlesscubemap.h>
-#include <qtechnique.h>
-#include <qenvironmentlight.h>
-#include <qblitframebuffer.h>
-#include <qstenciltestarguments.h>
-#include <qgeometryrenderer.h>
-#include <qpicktriangleevent.h>
-#include <qstenciloperation.h>
-#include <qparameter.h>
-#include <qpointsize.h>
-#include <qclearbuffers.h>
-#include <qtechniquefilter.h>
-#include <qtextureimagedata.h>
-#include <qfrontface.h>
-#include <qrenderstateset.h>
-#include <qraycasterhit.h>
-#include <qcolormask.h>
-#include <qrenderstate.h>
-#include <qblendequation.h>
-#include <qviewport.h>
-#include <qalphatest.h>
-#include <qcullface.h>
-#include <qrendertarget.h>
-#include <qtexture.h>
-#include <qabstractraycaster.h>
-#include <qfilterkey.h>
-#include <qtexturedata.h>
-#include <qnodepthmask.h>
-#include <qproximityfilter.h>
-#include <qrendertargetoutput.h>
-#include <qcameralens.h>
-#include <qshaderprogrambuilder.h>
-#include <qabstracttextureimage.h>
-#include <qsceneloader.h>
-#include <qrenderpass.h>
+#include <Qt3DRender/qraycaster.h>
+#include <Qt3DRender/qabstractfunctor.h>
+#include <Qt3DRender/qdepthtest.h>
+#include <Qt3DRender/qrendertargetselector.h>
+#include <Qt3DRender/qdithering.h>
+#include <Qt3DRender/qrenderpass.h>
+#include <Qt3DRender/qdispatchcompute.h>
+#include <Qt3DRender/qlevelofdetailswitch.h>
+#include <Qt3DRender/qscreenraycaster.h>
+#include <Qt3DRender/qblendequation.h>
+#include <Qt3DRender/qabstracttexture.h>
+#include <Qt3DRender/qpickingsettings.h>
+#include <Qt3DRender/qpaintedtextureimage.h>
+#include <Qt3DRender/qseamlesscubemap.h>
+#include <Qt3DRender/qspotlight.h>
+#include <Qt3DRender/qblitframebuffer.h>
+#include <Qt3DRender/qstenciloperationarguments.h>
+#include <Qt3DRender/qfrustumculling.h>
+#include <Qt3DRender/qstenciltestarguments.h>
+#include <Qt3DRender/qrenderpassfilter.h>
+#include <Qt3DRender/qcomputecommand.h>
+#include <Qt3DRender/qpickevent.h>
+#include <Qt3DRender/qrendersettings.h>
+#include <Qt3DRender/qpicktriangleevent.h>
+#include <Qt3DRender/qmultisampleantialiasing.h>
+#include <Qt3DRender/qtechniquefilter.h>
+#include <Qt3DRender/qattribute.h>
+#include <Qt3DRender/qgeometryrenderer.h>
+#include <Qt3DRender/qobjectpicker.h>
+#include <Qt3DRender/qframegraphnodecreatedchange.h>
+#include <Qt3DRender/qrenderstate.h>
+#include <Qt3DRender/qpointlight.h>
+#include <Qt3DRender/qrendersurfaceselector.h>
+#include <Qt3DRender/qtechnique.h>
+#include <Qt3DRender/qshaderprogrambuilder.h>
+#include <Qt3DRender/qenvironmentlight.h>
+#include <Qt3DRender/qtextureimagedata.h>
+#include <Qt3DRender/qabstracttextureimage.h>
+#include <Qt3DRender/qproximityfilter.h>
+#include <Qt3DRender/qtexturedata.h>
+#include <Qt3DRender/qabstractraycaster.h>
+#include <Qt3DRender/qshaderprogram.h>
+#include <Qt3DRender/qmesh.h>
+#include <Qt3DRender/qshaderdata.h>
+#include <Qt3DRender/qrenderaspect.h>
+#include <Qt3DRender/qnodepthmask.h>
+#include <Qt3DRender/qstenciloperation.h>
+#include <Qt3DRender/qviewport.h>
+#include <Qt3DRender/qcullface.h>
+#include <Qt3DRender/qframegraphnode.h>
+#include <Qt3DRender/qfrontface.h>
+#include <Qt3DRender/qblendequationarguments.h>
+#include <Qt3DRender/qstencilmask.h>
+#include <Qt3DRender/qmemorybarrier.h>
+#include <Qt3DRender/qalphacoverage.h>
+#include <Qt3DRender/qcameraselector.h>
+#include <Qt3DRender/qabstractlight.h>
+#include <Qt3DRender/qpickpointevent.h>
+#include <Qt3DRender/qlevelofdetailboundingsphere.h>
+#include <Qt3DRender/qsceneloader.h>
+#include <Qt3DRender/qtexture.h>
+#include <Qt3DRender/qparameter.h>
+#include <Qt3DRender/qfilterkey.h>
+#include <Qt3DRender/qpointsize.h>
+#include <Qt3DRender/qpicklineevent.h>
+#include <Qt3DRender/qlayerfilter.h>
+#include <Qt3DRender/qtextureimage.h>
+#include <Qt3DRender/qcolormask.h>
+#include <Qt3DRender/qstenciltest.h>
+#include <Qt3DRender/qtextureimagedatagenerator.h>
+#include <Qt3DRender/qcamera.h>
+#include <Qt3DRender/qsortpolicy.h>
+#include <Qt3DRender/qtexturewrapmode.h>
+#include <Qt3DRender/qalphatest.h>
+#include <Qt3DRender/qrendertargetoutput.h>
+#include <Qt3DRender/qrendercapture.h>
+#include <Qt3DRender/qbuffer.h>
+#include <Qt3DRender/qeffect.h>
+#include <Qt3DRender/qtexturegenerator.h>
+#include <Qt3DRender/qlinewidth.h>
+#include <Qt3DRender/qpolygonoffset.h>
+#include <Qt3DRender/qnodraw.h>
+#include <Qt3DRender/qrenderstateset.h>
+#include <Qt3DRender/qbuffercapture.h>
+#include <Qt3DRender/qgeometry.h>
+#include <Qt3DRender/qraycasterhit.h>
+#include <Qt3DRender/qlevelofdetail.h>
+#include <Qt3DRender/qclipplane.h>
+#include <Qt3DRender/qgeometryfactory.h>
+#include <Qt3DRender/qrendertarget.h>
+#include <Qt3DRender/qclearbuffers.h>
+#include <Qt3DRender/qscissortest.h>
+#include <Qt3DRender/qmaterial.h>
+#include <Qt3DRender/qlayer.h>
+#include <Qt3DRender/qcameralens.h>
+#include <Qt3DRender/qgraphicsapifilter.h>
+#include <Qt3DRender/qbufferdatagenerator.h>
+#include <Qt3DRender/qdirectionallight.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
