@@ -54,10 +54,10 @@
 #include <pyside2_qtwidgets_python.h>
 
 // Binded library includes
-#include <qcameraviewfinder.h>
-#include <qvideowidgetcontrol.h>
-#include <qvideowidget.h>
-#include <qgraphicsvideoitem.h>
+#include <QtMultimediaWidgets/qcameraviewfinder.h>
+#include <QtMultimediaWidgets/qvideowidget.h>
+#include <QtMultimediaWidgets/qgraphicsvideoitem.h>
+#include <QtMultimediaWidgets/qvideowidgetcontrol.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
