@@ -52,12 +52,12 @@
 #include <pyside2_qtcore_python.h>
 
 // Binded library includes
-#include <qgl.h>
-#include <qglbuffer.h>
-#include <qglcolormap.h>
-#include <qglpixelbuffer.h>
-#include <qglshaderprogram.h>
-#include <qglframebufferobject.h>
+#include <QtOpenGL/qgl.h>
+#include <QtOpenGL/qglbuffer.h>
+#include <QtOpenGL/qglframebufferobject.h>
+#include <QtOpenGL/qglcolormap.h>
+#include <QtOpenGL/qglpixelbuffer.h>
+#include <QtOpenGL/qglshaderprogram.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
