@@ -46,101 +46,109 @@
 
 #include <sbkpython.h>
 #include <sbkconverter.h>
-#include <sbkenum.h>
-#include <basewrapper.h>
-#include <bindingmanager.h>
-#include <memory>
-
-#include <pysidesignal.h>
 // Module Includes
-#include <pyside2_qtwidgets_python.h>
 #include <pyside2_qtgui_python.h>
 #include <pyside2_qtcore_python.h>
+#include <pyside2_qtwidgets_python.h>
 
 // Binded library includes
-#include <qprinter.h>
-#include <qpagesetupdialog.h>
-#include <qprintpreviewdialog.h>
-#include <qprinterinfo.h>
-#include <qprintengine.h>
-#include <qprintpreviewwidget.h>
-#include <qprintdialog.h>
-#include <qabstractprintdialog.h>
+#include <QtPrintSupport/qprintengine.h>
+#include <QtPrintSupport/qprintpreviewwidget.h>
+#include <QtPrintSupport/qprintdialog.h>
+#include <QtPrintSupport/qpagesetupdialog.h>
+#include <QtPrintSupport/qprintpreviewdialog.h>
+#include <QtPrintSupport/qprinterinfo.h>
+#include <QtPrintSupport/qabstractprintdialog.h>
+#include <QtPrintSupport/qprinter.h>
 // Conversion Includes - Primitive Types
-#include <QStringList>
-#include <QString>
-#include <signalmanager.h>
 #include <qabstractitemmodel.h>
+#include <QString>
+#include <QStringList>
+#include <signalmanager.h>
 
 // Conversion Includes - Container Types
-#include <QSet>
-#include <QList>
-#include <QMultiMap>
-#include <QMap>
+#include <pysideqflags.h>
 #include <QLinkedList>
+#include <QList>
+#include <QMap>
+#include <QMultiMap>
+#include <QPair>
+#include <QQueue>
+#include <QSet>
 #include <QStack>
 #include <QVector>
-#include <QQueue>
-#include <QPair>
-#include <pysideqflags.h>
 
 // Type indices
-#define SBK_QPRINTERINFO_IDX                                         23
-#define SBK_QPRINTENGINE_IDX                                         6
-#define SBK_QPRINTENGINE_PRINTENGINEPROPERTYKEY_IDX                  7
-#define SBK_QPRINTER_IDX                                             12
-#define SBK_QPRINTER_PRINTERMODE_IDX                                 20
-#define SBK_QPRINTER_ORIENTATION_IDX                                 15
-#define SBK_QPRINTER_PAGEORDER_IDX                                   17
-#define SBK_QPRINTER_COLORMODE_IDX                                   13
-#define SBK_QPRINTER_PAPERSOURCE_IDX                                 18
-#define SBK_QPRINTER_PRINTERSTATE_IDX                                21
-#define SBK_QPRINTER_OUTPUTFORMAT_IDX                                16
-#define SBK_QPRINTER_PRINTRANGE_IDX                                  19
-#define SBK_QPRINTER_UNIT_IDX                                        22
-#define SBK_QPRINTER_DUPLEXMODE_IDX                                  14
-#define SBK_QPRINTPREVIEWWIDGET_IDX                                  9
-#define SBK_QPRINTPREVIEWWIDGET_VIEWMODE_IDX                         10
-#define SBK_QPRINTPREVIEWWIDGET_ZOOMMODE_IDX                         11
-#define SBK_QPAGESETUPDIALOG_IDX                                     4
-#define SBK_QABSTRACTPRINTDIALOG_IDX                                 0
-#define SBK_QABSTRACTPRINTDIALOG_PRINTRANGE_IDX                      2
-#define SBK_QABSTRACTPRINTDIALOG_PRINTDIALOGOPTION_IDX               1
-#define SBK_QFLAGS_QABSTRACTPRINTDIALOG_PRINTDIALOGOPTION__IDX       3
-#define SBK_QPRINTDIALOG_IDX                                         5
-#define SBK_QPRINTPREVIEWDIALOG_IDX                                  8
-#define SBK_QtPrintSupport_IDX_COUNT                                 24
-
+enum : int {
+    SBK_QABSTRACTPRINTDIALOG_IDX                             = 0,
+    SBK_QABSTRACTPRINTDIALOG_PRINTRANGE_IDX                  = 2,
+    SBK_QABSTRACTPRINTDIALOG_PRINTDIALOGOPTION_IDX           = 1,
+    SBK_QFLAGS_QABSTRACTPRINTDIALOG_PRINTDIALOGOPTION_IDX    = 3,
+    SBK_QPAGESETUPDIALOG_IDX                                 = 4,
+    SBK_QPRINTDIALOG_IDX                                     = 5,
+    SBK_QPRINTENGINE_IDX                                     = 6,
+    SBK_QPRINTENGINE_PRINTENGINEPROPERTYKEY_IDX              = 7,
+    SBK_QPRINTPREVIEWDIALOG_IDX                              = 8,
+    SBK_QPRINTPREVIEWWIDGET_IDX                              = 9,
+    SBK_QPRINTPREVIEWWIDGET_VIEWMODE_IDX                     = 10,
+    SBK_QPRINTPREVIEWWIDGET_ZOOMMODE_IDX                     = 11,
+    SBK_QPRINTER_IDX                                         = 12,
+    SBK_QPRINTER_PRINTERMODE_IDX                             = 20,
+    SBK_QPRINTER_ORIENTATION_IDX                             = 15,
+    SBK_QPRINTER_PAGEORDER_IDX                               = 17,
+    SBK_QPRINTER_COLORMODE_IDX                               = 13,
+    SBK_QPRINTER_PAPERSOURCE_IDX                             = 18,
+    SBK_QPRINTER_PRINTERSTATE_IDX                            = 21,
+    SBK_QPRINTER_OUTPUTFORMAT_IDX                            = 16,
+    SBK_QPRINTER_PRINTRANGE_IDX                              = 19,
+    SBK_QPRINTER_UNIT_IDX                                    = 22,
+    SBK_QPRINTER_DUPLEXMODE_IDX                              = 14,
+    SBK_QPRINTERINFO_IDX                                     = 23,
+    SBK_QtPrintSupport_IDX_COUNT                             = 24
+};
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_QtPrintSupportTypes;
 
+// This variable stores the Python module object exported by this module.
+extern PyObject* SbkPySide2_QtPrintSupportModuleObject;
+
 // This variable stores all type converters exported by this module.
 extern SbkConverter** SbkPySide2_QtPrintSupportTypeConverters;
 
 // Converter indices
-#define SBK_QTPRINTSUPPORT_QLIST_QPRINTERINFO_IDX                    0 // QList<QPrinterInfo >
-#define SBK_QTPRINTSUPPORT_QLIST_QPRINTER_DUPLEXMODE_IDX             1 // QList<QPrinter::DuplexMode >
-#define SBK_QTPRINTSUPPORT_QLIST_QPAGESIZE_IDX                       2 // QList<QPageSize >
-#define SBK_QTPRINTSUPPORT_QLIST_QPAGEDPAINTDEVICE_PAGESIZE_IDX      3 // QList<QPagedPaintDevice::PageSize >
-#define SBK_QTPRINTSUPPORT_QLIST_INT_IDX                             4 // QList<int >
-#define SBK_QTPRINTSUPPORT_QPAIR_QSTRING_QSIZEF_IDX                  5 // QPair<QString,QSizeF >
-#define SBK_QTPRINTSUPPORT_QLIST_QPAIR_QSTRING_QSIZEF_IDX            6 // QList<QPair< QString,QSizeF > >
-#define SBK_QTPRINTSUPPORT_QLIST_QACTIONPTR_IDX                      7 // QList<QAction* >
-#define SBK_QTPRINTSUPPORT_QLIST_QWIDGETPTR_IDX                      8 // const QList<QWidget* > &
-#define SBK_QTPRINTSUPPORT_QLIST_QVARIANT_IDX                        9 // QList<QVariant >
-#define SBK_QTPRINTSUPPORT_QLIST_QSTRING_IDX                         10 // QList<QString >
-#define SBK_QTPRINTSUPPORT_QMAP_QSTRING_QVARIANT_IDX                 11 // QMap<QString,QVariant >
-#define SBK_QtPrintSupport_CONVERTERS_IDX_COUNT                      12
-
+enum : int {
+    SBK_QTPRINTSUPPORT_QLIST_QACTIONPTR_IDX                  = 0, // QList<QAction* >
+    SBK_QTPRINTSUPPORT_QLIST_QWIDGETPTR_IDX                  = 1, // const QList<QWidget* > &
+    SBK_QTPRINTSUPPORT_QLIST_INT_IDX                         = 2, // QList<int >
+    SBK_QTPRINTSUPPORT_QLIST_QPRINTERINFO_IDX                = 3, // QList<QPrinterInfo >
+    SBK_QTPRINTSUPPORT_QLIST_QPRINTER_DUPLEXMODE_IDX         = 4, // QList<QPrinter::DuplexMode >
+    SBK_QTPRINTSUPPORT_QLIST_QPAGESIZE_IDX                   = 5, // QList<QPageSize >
+    SBK_QTPRINTSUPPORT_QLIST_QPAGEDPAINTDEVICE_PAGESIZE_IDX  = 6, // QList<QPagedPaintDevice::PageSize >
+    SBK_QTPRINTSUPPORT_QPAIR_QSTRING_QSIZEF_IDX              = 7, // QPair<QString,QSizeF >
+    SBK_QTPRINTSUPPORT_QLIST_QPAIR_QSTRING_QSIZEF_IDX        = 8, // QList<QPair< QString,QSizeF > >
+    SBK_QTPRINTSUPPORT_QLIST_QVARIANT_IDX                    = 9, // QList<QVariant >
+    SBK_QTPRINTSUPPORT_QLIST_QSTRING_IDX                     = 10, // QList<QString >
+    SBK_QTPRINTSUPPORT_QMAP_QSTRING_QVARIANT_IDX             = 11, // QMap<QString,QVariant >
+    SBK_QtPrintSupport_CONVERTERS_IDX_COUNT                  = 12
+};
 // Macros for type check
 
 namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::QPrinterInfo >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtPrintSupportTypes[SBK_QPRINTERINFO_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QAbstractPrintDialog::PrintRange >() { return SbkPySide2_QtPrintSupportTypes[SBK_QABSTRACTPRINTDIALOG_PRINTRANGE_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QAbstractPrintDialog::PrintDialogOption >() { return SbkPySide2_QtPrintSupportTypes[SBK_QABSTRACTPRINTDIALOG_PRINTDIALOGOPTION_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QFlags<QAbstractPrintDialog::PrintDialogOption> >() { return SbkPySide2_QtPrintSupportTypes[SBK_QFLAGS_QABSTRACTPRINTDIALOG_PRINTDIALOGOPTION_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QAbstractPrintDialog >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtPrintSupportTypes[SBK_QABSTRACTPRINTDIALOG_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QPageSetupDialog >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtPrintSupportTypes[SBK_QPAGESETUPDIALOG_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QPrintDialog >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtPrintSupportTypes[SBK_QPRINTDIALOG_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QPrintEngine::PrintEnginePropertyKey >() { return SbkPySide2_QtPrintSupportTypes[SBK_QPRINTENGINE_PRINTENGINEPROPERTYKEY_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QPrintEngine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtPrintSupportTypes[SBK_QPRINTENGINE_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QPrintPreviewDialog >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtPrintSupportTypes[SBK_QPRINTPREVIEWDIALOG_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QPrintPreviewWidget::ViewMode >() { return SbkPySide2_QtPrintSupportTypes[SBK_QPRINTPREVIEWWIDGET_VIEWMODE_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QPrintPreviewWidget::ZoomMode >() { return SbkPySide2_QtPrintSupportTypes[SBK_QPRINTPREVIEWWIDGET_ZOOMMODE_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QPrintPreviewWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtPrintSupportTypes[SBK_QPRINTPREVIEWWIDGET_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QPrinter::PrinterMode >() { return SbkPySide2_QtPrintSupportTypes[SBK_QPRINTER_PRINTERMODE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QPrinter::Orientation >() { return SbkPySide2_QtPrintSupportTypes[SBK_QPRINTER_ORIENTATION_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QPrinter::PageOrder >() { return SbkPySide2_QtPrintSupportTypes[SBK_QPRINTER_PAGEORDER_IDX]; }
@@ -152,16 +160,7 @@ template<> inline PyTypeObject* SbkType< ::QPrinter::PrintRange >() { return Sbk
 template<> inline PyTypeObject* SbkType< ::QPrinter::Unit >() { return SbkPySide2_QtPrintSupportTypes[SBK_QPRINTER_UNIT_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QPrinter::DuplexMode >() { return SbkPySide2_QtPrintSupportTypes[SBK_QPRINTER_DUPLEXMODE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QPrinter >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtPrintSupportTypes[SBK_QPRINTER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QPrintPreviewWidget::ViewMode >() { return SbkPySide2_QtPrintSupportTypes[SBK_QPRINTPREVIEWWIDGET_VIEWMODE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QPrintPreviewWidget::ZoomMode >() { return SbkPySide2_QtPrintSupportTypes[SBK_QPRINTPREVIEWWIDGET_ZOOMMODE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QPrintPreviewWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtPrintSupportTypes[SBK_QPRINTPREVIEWWIDGET_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QPageSetupDialog >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtPrintSupportTypes[SBK_QPAGESETUPDIALOG_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QAbstractPrintDialog::PrintRange >() { return SbkPySide2_QtPrintSupportTypes[SBK_QABSTRACTPRINTDIALOG_PRINTRANGE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QAbstractPrintDialog::PrintDialogOption >() { return SbkPySide2_QtPrintSupportTypes[SBK_QABSTRACTPRINTDIALOG_PRINTDIALOGOPTION_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QFlags<QAbstractPrintDialog::PrintDialogOption> >() { return SbkPySide2_QtPrintSupportTypes[SBK_QFLAGS_QABSTRACTPRINTDIALOG_PRINTDIALOGOPTION__IDX]; }
-template<> inline PyTypeObject* SbkType< ::QAbstractPrintDialog >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtPrintSupportTypes[SBK_QABSTRACTPRINTDIALOG_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QPrintDialog >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtPrintSupportTypes[SBK_QPRINTDIALOG_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QPrintPreviewDialog >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtPrintSupportTypes[SBK_QPRINTPREVIEWDIALOG_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QPrinterInfo >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtPrintSupportTypes[SBK_QPRINTERINFO_IDX]); }
 
 } // namespace Shiboken
 
